@@ -431,7 +431,7 @@ class BigQueryExecutor:
                DELETE
                  `{backfill_dataset_id}.{table_id}`
                WHERE
-                 {partition_field} BETWEEN
+                 CAST({partition_field} AS DATE) BETWEEN
                    CAST('{from_partition}' AS DATE) AND CAST('{to_partition}' AS DATE)
                """
 
