@@ -367,6 +367,7 @@ def write_text_file(
 def slice_list_to_chunks(lst, n):
     """
     Slice a list into chunks of size n.
+
     Args:
         list
         int
@@ -376,3 +377,38 @@ def slice_list_to_chunks(lst, n):
     chunks = [lst[x:x+n] for x in range(0, len(lst), n)]
 
     return chunks
+
+
+def flatten_df_columns(df: pd.DataFrame) -> pd.DataFrame:
+    """
+    Flatten repeated fields in a pandas dataframe an unnest columns.
+    (for single layer nesting only)
+    Checks if column is nested - if not raises AttributeError and appends
+    original column.
+
+    Args:
+        df
+    Returns:
+        df
+    """
+    # explode repeated fields
+    for col in df.columns:
+        df = df.explode(col)
+    df = df.reset_index(drop=True)
+
+    # unnest
+    df_flat = pd.DataFrame()
+    for col in df.columns:
+        try:
+            col_flat = df[col].apply(lambda x: {} if pd.isna(x) else x)
+            col_flat = pd.json_normalize(col_flat)
+            if col_flat.shape[1] == 1:
+                raise AttributeError
+            else:
+                col_flat.columns = [f"{col}__{x}" for x in col_flat.columns]
+                df_flat = pd.concat([df_flat, col_flat], axis=1)
+        except AttributeError:
+            df_flat = pd.concat([df_flat, df[col]], axis=1)
+    df_flat = df_flat.reset_index(drop=True)
+
+    return df_flat
